==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/ru/commands.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>CommandDialog</name>
    <message>
        <source>&lt;Back</source>
        <translation>&lt;Назад</translation>
    </message>
    <message>
        <source>Next&gt;</source>
        <translation>Вперёд&gt;</translation>
    </message>
    <message>
        <source>Complete</source>
        <translation>Завершено</translation>
    </message>
    <message>
        <source>Command execution completed.</source>
        <translation>Выполнение команды завершено.</translation>
    </message>
    <message>
        <source>Command execution canceled.</source>
        <translation>Выполнение команды отменено.</translation>
    </message>
    <message>
        <source>Requested operation failed: %1</source>
        <translation>Запрошенная операция не выполнена: %1</translation>
    </message>
    <message>
        <source>Executing command &apos;%1&apos; at %2</source>
        <translation>Выполнение команды &apos;%1&apos; на %2</translation>
    </message>
    <message>
        <source>Waiting for host response ...</source>
        <translation>Ожидание ответа хоста ...</translation>
    </message>
    <message>
        <source>Error: Can&apos;t send request to host.</source>
        <translation>Ошибка: Невозможно отправить запрос на хост.</translation>
    </message>
</context>
<context>
    <name>Commands</name>
    <message>
        <source>Ad-Hoc Commands</source>
        <translation>Ad-Hoc Команды</translation>
    </message>
    <message>
        <source>Can not understand the specified action</source>
        <translation>Не поддерживаемая команда</translation>
    </message>
    <message>
        <source>Can not accept the specified action</source>
        <translation>Неприемлемая команда</translation>
    </message>
    <message>
        <source>Can not accept the specified language/locale</source>
        <translation>Неприемлемый язык или локаль</translation>
    </message>
    <message>
        <source>The data form did not provide one or more required fields</source>
        <translation>В форме не заполнено одно или несколько обязательных полей</translation>
    </message>
    <message>
        <source>Specified session not present</source>
        <translation>Указанная сессия не существует</translation>
    </message>
    <message>
        <source>Specified session is no longer active</source>
        <translation>Указанная сессия более не активна</translation>
    </message>
    <message>
        <source>Execute</source>
        <translation>Выполнить</translation>
    </message>
    <message>
        <source>Commands</source>
        <translation>Команды</translation>
    </message>
    <message>
        <source>Request commands</source>
        <translation>Запросить команды</translation>
    </message>
    <message>
        <source>Allows to perform special commands provided by various services</source>
        <translation>Позволяет выполнять специальные команды предоставляемые различными сервисами</translation>
    </message>
    <message>
        <source>Supports the running or performing of the special services commands</source>
        <translation>Поддерживает запуск или выполнение специальных сервисных команд</translation>
    </message>
    <message>
        <source>Forbidden</source>
        <translation>Запрещено</translation>
    </message>
</context>
</TS>

==> vacuum-1.1.1.tar.xz: vacuum-1.1.1/src/translations/ru/commands.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>CommandDialog</name>
    <message>
        <source>&lt;Back</source>
        <translation>&lt;Назад</translation>
    </message>
    <message>
        <source>Next&gt;</source>
        <translation>Вперёд&gt;</translation>
    </message>
    <message>
        <source>Complete</source>
        <translation>Завершить</translation>
    </message>
    <message>
        <source>Command execution completed.</source>
        <translation>Выполнение команды завершено.</translation>
    </message>
    <message>
        <source>Command execution canceled.</source>
        <translation>Выполнение команды отменено.</translation>
    </message>
    <message>
        <source>Requested operation failed: %1</source>
        <translation>Запрошенная операция не выполнена: %1</translation>
    </message>
    <message>
        <source>Executing command &apos;%1&apos; at %2</source>
        <translation>Выполнение команды &apos;%1&apos; на %2</translation>
    </message>
    <message>
        <source>Waiting for host response ...</source>
        <translation>Ожидание ответа хоста ...</translation>
    </message>
    <message>
        <source>Error: Can&apos;t send request to host.</source>
        <translation>Ошибка: Невозможно отправить запрос на хост.</translation>
    </message>
</context>
<context>
    <name>Commands</name>
    <message>
        <source>Ad-Hoc Commands</source>
        <translation>Ad-Hoc Команды</translation>
    </message>
    <message>
        <source>Can not understand the specified action</source>
        <translation>Не поддерживаемая команда</translation>
    </message>
    <message>
        <source>Can not accept the specified action</source>
        <translation>Неприемлемая команда</translation>
    </message>
    <message>
        <source>Can not accept the specified language/locale</source>
        <translation>Неприемлемый язык или локаль</translation>
    </message>
    <message>
        <source>The data form did not provide one or more required fields</source>
        <translation>В форме не заполнено одно или несколько обязательных полей</translation>
    </message>
    <message>
        <source>Specified session not present</source>
        <translation>Указанная сессия не существует</translation>
    </message>
    <message>
        <source>Specified session is no longer active</source>
        <translation>Указанная сессия более не активна</translation>
    </message>
    <message>
        <source>Execute</source>
        <translation>Выполнить</translation>
    </message>
    <message>
        <source>Commands</source>
        <translation>Команды</translation>
    </message>
    <message>
        <source>Request commands</source>
        <translation>Запросить команды</translation>
    </message>
    <message>
        <source>Allows to perform special commands provided by various services</source>
        <translation>Позволяет выполнять специальные команды предоставляемые различными сервисами</translation>
    </message>
    <message>
        <source>Supports the running or performing of the special services commands</source>
        <translation>Поддерживает запуск или выполнение специальных сервисных команд</translation>
    </message>
    <message>
        <source>Forbidden</source>
        <translation>Запрещено</translation>
    </message>
</context>
</TS>
